summaryrefslogtreecommitdiffstats
path: root/src/entryview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryview.cpp')
-rw-r--r--src/entryview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/entryview.cpp b/src/entryview.cpp
index 2965405..3499adc 100644
--- a/src/entryview.cpp
+++ b/src/entryview.cpp
@@ -46,7 +46,7 @@ EntryView::EntryView(TQWidget* parent_, const char* name_) : KHTMLPart(parent_,
setJavaEnabled(false);
setMetaRefreshEnabled(false);
setPluginsEnabled(false);
- clear(); // needed for initial tqlayout
+ clear(); // needed for initial layout
view()->setAcceptDrops(true);
DropHandler* drophandler = new DropHandler(this);
@@ -76,7 +76,7 @@ void EntryView::clear() {
write(m_textToShow);
}
end();
- view()->tqlayout(); // I need this because some of the margins and widths may get messed up
+ view()->layout(); // I need this because some of the margins and widths may get messed up
}
void EntryView::showEntry(Data::EntryPtr entry_) {
@@ -158,7 +158,7 @@ void EntryView::showEntry(Data::EntryPtr entry_) {
write(html);
end();
// not need anymore?
- view()->tqlayout(); // I need this because some of the margins and widths may get messed up
+ view()->layout(); // I need this because some of the margins and widths may get messed up
}
void EntryView::showText(const TQString& text_) {